@@ -11,11 +11,7 @@
 // Try to use as much of the GNU C library as possible:
 #define _GNU_SOURCE
 
-#include "compiled.h"    // GAP headers
-
-#if GAP_KERNEL_MAJOR_VERSION >= 6
-#include "profile.h"
-#endif
+#include "gap_all.h"    // GAP headers
 
 #undef PACKAGE
 #undef PACKAGE_BUGREPORT
